<?php

declare(strict_types = 1);

namespace Drupal\entity_visibility_preview\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\entity_visibility_preview\EntityVisibilityPreviewConditionPluginManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Preview form.
 */
class PreviewForm extends FormBase {

  /**
   * Instance of EntityVisibilityPreviewConditionPluginManager service.
   *
   * @var \Drupal\entity_visibility_preview\EntityVisibilityPreviewConditionPluginManager
   */
  protected $entityVisibilityPreviewConditionPluginManager;

  /**
   * PreviewForm constructor.
   *
   * @param \Drupal\entity_visibility_preview\EntityVisibilityPreviewConditionPluginManager $manager
   *   The Condition plugin manager.
   */
  public function __construct(EntityVisibilityPreviewConditionPluginManager $manager) {
    $this->entityVisibilityPreviewConditionPluginManager = $manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.entity_visibility_preview_condition')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_visibility_preview_preview_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $plugins = $this->entityVisibilityPreviewConditionPluginManager->getDefinitions();
    foreach ($plugins as $plugin_id => $plugin_definition) {
      /** @var \Drupal\entity_visibility_preview\EntityVisibilityPreviewConditionInterface $entityVisibilityPreviewCondition */
      $entityVisibilityPreviewCondition = $this->entityVisibilityPreviewConditionPluginManager->createInstance($plugin_id);
      $entityVisibilityPreviewCondition->previewBuildForm($form, $form_state);
    }

    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Update'),
    ];
    $form['actions']['reset'] = [
      '#type' => 'submit',
      '#submit' => ['::resetForm'],
      '#value' => $this->t('Reset to current date and normal state'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $plugins = $this->entityVisibilityPreviewConditionPluginManager->getDefinitions();
    foreach ($plugins as $plugin_id => $plugin_definition) {
      /** @var \Drupal\entity_visibility_preview\EntityVisibilityPreviewConditionInterface $entityVisibilityPreviewCondition */
      $entityVisibilityPreviewCondition = $this->entityVisibilityPreviewConditionPluginManager->createInstance($plugin_id);
      $entityVisibilityPreviewCondition->previewSubmitForm($form, $form_state);
    }
  }

  /**
   * Submit callback for the reset button.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function resetForm(array &$form, FormStateInterface $form_state) {
    $plugins = $this->entityVisibilityPreviewConditionPluginManager->getDefinitions();
    foreach ($plugins as $plugin_id => $plugin_definition) {
      /** @var \Drupal\entity_visibility_preview\EntityVisibilityPreviewConditionInterface $entityVisibilityPreviewCondition */
      $entityVisibilityPreviewCondition = $this->entityVisibilityPreviewConditionPluginManager->createInstance($plugin_id);
      $entityVisibilityPreviewCondition->previewResetForm();
    }
  }

}
