<?php

declare(strict_types = 1);

namespace Drupal\entity_visibility_preview\Service;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;

/**
 * Helper for taxonomies.
 */
class EntityVisibilityPreviewTaxonomyHelper implements EntityVisibilityPreviewTaxonomyHelperInterface {

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Logger channel factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * PreviewForm constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity type manager.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $loggerChannelFactory
   *   The logger channel factory.
   */
  public function __construct(
    EntityTypeManagerInterface $entityTypeManager,
    LoggerChannelFactoryInterface $loggerChannelFactory
  ) {
    $this->entityTypeManager = $entityTypeManager;
    $this->logger = $loggerChannelFactory->get(self::LOGGER_CHANNEL);
  }

  /**
   * Returns an array of tids given an array of uuids.
   *
   * @param array $uuids
   *   The uuids to load.
   *
   * @return array
   *   An array of tids.
   */
  public function getTidsFromUuids(array $uuids) : array {
    try {
      return $this->entityTypeManager->getStorage('taxonomy_term')
        ->getQuery()
        ->condition('uuid', $uuids, 'IN')
        ->execute();
    }
    catch (\Exception $e) {
      return [];
    }
  }

  /**
   * Returns an array of uuids given an array of tids.
   *
   * @param array $tids
   *   An array of tids to transform to uuids.
   *
   * @return array
   *   An array of uuids.
   */
  public function getUuidsFromTids(array $tids) : array {
    try {
      $uuids = [];
      $terms = $this->entityTypeManager->getStorage('taxonomy_term')
        ->loadMultiple($tids);

      foreach ($terms as $term) {
        $uuids[] = $term->uuid();
      }
      return $uuids;
    }
    catch (\Exception $e) {
      return [];
    }
  }

}
